==> mroylib_min-1.7.63.tar.gz: mroylib_min-1.7.63/mroylib/cmd.py <==
from argparse import ArgumentParser
from qlib.log import log
from qlib.data import Cache,mysql_to_sqlite
import logging
import chardet, os, sys



parser = ArgumentParser()

parser.add_argument("file_or_obj", nargs='*', help=" file or some object to handle")
parser.add_argument("-e","--encoding"  , default=None, help="change encoding: utf , gbk, ...")
parser.add_argument("--to-elasticsearch", action='store_true',default=False, help="import sql files to elastic search ...")
parser.add_argument("--to-sqlite", default=None,  help="import mysql files to sqlite ...")
parser.add_argument("--url", default='http://localhost:9200', help="elastic search url: default-> http://localhost:9200")
parser.add_argument("--database", default='test4', help="set database")
parser.add_argument("--user", default='root', help="set user")
parser.add_argument("--passwd", default='', help="set password")



@log(logging.INFO)
def main():
    
    args = parser.parse_args()
    e = None
    for f in args.file_or_obj:
        if os.path.exists(f):
            os.system("file " + f)
            with open(f, "rb") as fp:
                ws = fp.read(2000)
                e = chardet.detect(ws)
                logging.info(str(e))
            # logging.info("wbt")
    if args.encoding:
                        
                
        if not ws or not e:
            logging.error("not load success")
            return 

        with open(args.file_or_obj + ".bak", 'wb') as fp2:
            fp2.write(ws.decode(e['encoding']).encode(args.encoding))
            
        logging.info(e['encoding'] + ' -> ' + args.encoding )

    if args.to_elasticsearch:
        for f in args.file_or_obj:
            Cache.export_to_es_from_db_file(f, args.url)
            print(f"{f} -> {args.url}")
    elif args.to_sqlite:
        mysql_to_sqlite(args.to_sqlite, database=args.database, user=args.user, password=args.passwd)

==> mroylib_min-1.7.64.tar.gz: mroylib_min-1.7.64/mroylib/cmd.py <==
from argparse import ArgumentParser
from qlib.log import log
from qlib.data import Cache,mysql_to_sqlite,sqlite_to_mysql
import logging
import chardet, os, sys



parser = ArgumentParser()

parser.add_argument("file_or_obj", nargs='*', help=" file or some object to handle")
parser.add_argument("-e","--encoding"  , default=None, help="change encoding: utf , gbk, ...")
parser.add_argument("--to-elasticsearch", action='store_true',default=False, help="import sql files to elastic search ...")
parser.add_argument("--to-sqlite", action='store_true',default=False,  help="import mysql files to sqlite ...")
parser.add_argument("--to-mysql", action='store_true',default=False,  help="import sqlite files to mysql  ...")
parser.add_argument("--url", default='http://localhost:9200', help="elastic search url: default-> http://localhost:9200")
parser.add_argument("--database", default='test4', help="set database")
parser.add_argument("--user", default='root', help="set user")
parser.add_argument("--passwd", default='', help="set password")



@log(logging.INFO)
def main():
    
    args = parser.parse_args()
    e = None
    for f in args.file_or_obj:
        if os.path.exists(f):
            os.system("file " + f)
            with open(f, "rb") as fp:
                ws = fp.read(2000)
                e = chardet.detect(ws)
                logging.info(str(e))
            # logging.info("wbt")
    if args.encoding:
                        
                
        if not ws or not e:
            logging.error("not load success")
            return 

        with open(args.file_or_obj + ".bak", 'wb') as fp2:
            fp2.write(ws.decode(e['encoding']).encode(args.encoding))
            
        logging.info(e['encoding'] + ' -> ' + args.encoding )

    if args.to_elasticsearch:
        for f in args.file_or_obj:
            Cache.export_to_es_from_db_file(f, args.url)
            print(f"{f} -> {args.url}")
    elif args.to_sqlite:
        for f in args.file_or_obj:
            mysql_to_sqlite(f, database=args.database, user=args.user, password=args.passwd)
    elif args.to_mysql:
        for f in args.file_or_obj:
            sqlite_to_mysql(f, database=args.database, user=args.user, password=args.passwd)
